@@ -4,50 +4,50 @@
 <context>
     <name>DialogGraph</name>
     <message>
-        <location filename="../ui/graphDialog.ui" line="14"/>
+        <location filename="../ui/graphDialog.ui" line="17"/>
         <source>Graph</source>
         <translation>Grafik</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="23"/>
+        <location filename="../ui/graphDialog.ui" line="26"/>
         <source>Please wait ...</source>
         <translation>Harap tunggu...</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="70"/>
         <location filename="../ui/graphDialog.ui" line="73"/>
+        <location filename="../ui/graphDialog.ui" line="76"/>
         <source>Zoom Out</source>
         <translation>Zoom Out</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="93"/>
         <location filename="../ui/graphDialog.ui" line="96"/>
+        <location filename="../ui/graphDialog.ui" line="99"/>
         <source>Zoom In</source>
         <translation>Memperbesar</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="123"/>
+        <location filename="../ui/graphDialog.ui" line="126"/>
         <source>Number of levels:</source>
         <translation>Jumlah tingkat:</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="153"/>
         <location filename="../ui/graphDialog.ui" line="156"/>
         <location filename="../ui/graphDialog.ui" line="159"/>
+        <location filename="../ui/graphDialog.ui" line="162"/>
         <source>Save to DOT file</source>
         <translation>Menyimpan DOT file</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="172"/>
         <location filename="../ui/graphDialog.ui" line="175"/>
         <location filename="../ui/graphDialog.ui" line="178"/>
+        <location filename="../ui/graphDialog.ui" line="181"/>
         <source>Save Image</source>
         <translation>Simpan gambar</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="191"/>
         <location filename="../ui/graphDialog.ui" line="194"/>
         <location filename="../ui/graphDialog.ui" line="197"/>
+        <location filename="../ui/graphDialog.ui" line="200"/>
         <source>Close</source>
         <translation>Dekat</translation>
     </message>
@@ -55,211 +55,217 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../ui/mainWindow.ui" line="14"/>
+        <location filename="../ui/mainWindow.ui" line="17"/>
         <source>CodeQuery</source>
         <translation>CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="27"/>
         <location filename="../ui/mainWindow.ui" line="30"/>
+        <location filename="../ui/mainWindow.ui" line="33"/>
         <source>Open Database</source>
         <translation>Buka Database</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="76"/>
+        <location filename="../ui/mainWindow.ui" line="79"/>
         <source>Auto-complete</source>
         <translation>Auto-lengkap</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="90"/>
+        <location filename="../ui/mainWindow.ui" line="93"/>
         <source>Exact match</source>
         <translation>Pencocokan sama persis</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="104"/>
         <location filename="../ui/mainWindow.ui" line="107"/>
+        <location filename="../ui/mainWindow.ui" line="110"/>
         <source>File path filter</source>
         <translation>File path filter</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="110"/>
+        <location filename="../ui/mainWindow.ui" line="113"/>
         <source>Filter</source>
         <translation>Filter</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="126"/>
         <location filename="../ui/mainWindow.ui" line="129"/>
+        <location filename="../ui/mainWindow.ui" line="132"/>
         <source>File path filter, wildcard searches (* and ?) are supported</source>
         <translation>File path filter, pencarian wildcard (* dan?) yang didukung</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="152"/>
         <location filename="../ui/mainWindow.ui" line="155"/>
+        <location filename="../ui/mainWindow.ui" line="158"/>
         <source>Previous search term</source>
         <translation>Istilah penelusuran sebelumnya</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="175"/>
         <location filename="../ui/mainWindow.ui" line="178"/>
+        <location filename="../ui/mainWindow.ui" line="181"/>
         <source>Next search term</source>
         <translation>Istilah pencarian berikutnya</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="204"/>
         <location filename="../ui/mainWindow.ui" line="207"/>
+        <location filename="../ui/mainWindow.ui" line="210"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>Jika pencocokan sama persis dimatikan, pencarian wildcard (* dan?) yang didukung</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="226"/>
         <location filename="../ui/mainWindow.ui" line="229"/>
+        <location filename="../ui/mainWindow.ui" line="232"/>
         <source>Search</source>
         <translation>Cari</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="249"/>
         <location filename="../ui/mainWindow.ui" line="252"/>
+        <location filename="../ui/mainWindow.ui" line="255"/>
         <source>Paste and Search</source>
         <translation>Tempel dan telusuri</translation>
     </message>
     <message>
         <location filename="../ui/mainWindow.ui" line="275"/>
         <location filename="../ui/mainWindow.ui" line="278"/>
+        <source>List of all files</source>
+        <translation>Daftar semua file</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="301"/>
+        <location filename="../ui/mainWindow.ui" line="304"/>
         <source>Draw graph</source>
         <translation>Menggambar grafik</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="335"/>
-        <location filename="../ui/mainWindow.ui" line="338"/>
+        <location filename="../ui/mainWindow.ui" line="361"/>
+        <location filename="../ui/mainWindow.ui" line="364"/>
         <source>Previous File</source>
         <translation>File sebelumnya</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="358"/>
-        <location filename="../ui/mainWindow.ui" line="361"/>
+        <location filename="../ui/mainWindow.ui" line="384"/>
+        <location filename="../ui/mainWindow.ui" line="387"/>
         <source>Next File</source>
         <translation>Sebelumnya/berikutnya</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="381"/>
-        <location filename="../ui/mainWindow.ui" line="384"/>
+        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="410"/>
         <source>Open in Editor</source>
         <translation>Terbuka di Editor</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="404"/>
-        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="430"/>
+        <location filename="../ui/mainWindow.ui" line="433"/>
         <source>Go to selected line</source>
         <translation>Pergi ke saluran yang dipilih</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="427"/>
-        <location filename="../ui/mainWindow.ui" line="430"/>
+        <location filename="../ui/mainWindow.ui" line="453"/>
+        <location filename="../ui/mainWindow.ui" line="456"/>
         <source>Reduce font size</source>
         <translation>Mengurangi ukuran font</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="450"/>
-        <location filename="../ui/mainWindow.ui" line="453"/>
+        <location filename="../ui/mainWindow.ui" line="476"/>
+        <location filename="../ui/mainWindow.ui" line="479"/>
         <source>Increase font size</source>
         <translation>Meningkatkan ukuran font</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="480"/>
-        <location filename="../ui/mainWindow.ui" line="483"/>
+        <location filename="../ui/mainWindow.ui" line="506"/>
+        <location filename="../ui/mainWindow.ui" line="509"/>
         <source>Copy, paste and search</source>
         <translation>Salin, Tempel dan telusuri</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="503"/>
-        <location filename="../ui/mainWindow.ui" line="506"/>
+        <location filename="../ui/mainWindow.ui" line="529"/>
+        <location filename="../ui/mainWindow.ui" line="532"/>
         <source>Symbol search only for paste and search</source>
         <translation>Simbol pencarian hanya untuk Tempel dan telusuri</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="509"/>
+        <location filename="../ui/mainWindow.ui" line="535"/>
         <source>Symbol only</source>
         <translation>Simbol hanya</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="523"/>
-        <location filename="../ui/mainWindow.ui" line="526"/>
+        <location filename="../ui/mainWindow.ui" line="549"/>
+        <location filename="../ui/mainWindow.ui" line="552"/>
         <source>Previous search result in this file</source>
         <translation>Hasil penelusuran sebelumnya dalam file ini</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="546"/>
-        <location filename="../ui/mainWindow.ui" line="549"/>
+        <location filename="../ui/mainWindow.ui" line="572"/>
+        <location filename="../ui/mainWindow.ui" line="575"/>
         <source>Next search result in this file</source>
         <translation>Hasil pencarian berikutnya dalam file ini</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="581"/>
+        <location filename="../ui/mainWindow.ui" line="607"/>
         <source>FilePath:0</source>
         <translation>FilePath:0</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="610"/>
+        <location filename="../ui/mainWindow.ui" line="636"/>
         <source>Sort by line number</source>
         <translation>Urut berdasarkan nomor baris</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="615"/>
+        <location filename="../ui/mainWindow.ui" line="641"/>
         <source>Sort by name</source>
         <translation>Urut berdasarkan nama</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="665"/>
+        <location filename="../ui/mainWindow.ui" line="691"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="672"/>
+        <location filename="../ui/mainWindow.ui" line="698"/>
         <source>Options</source>
         <translation>Pilihan</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="680"/>
+        <location filename="../ui/mainWindow.ui" line="706"/>
         <source>Help</source>
         <translation>Tolong</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="692"/>
+        <location filename="../ui/mainWindow.ui" line="718"/>
         <source>Exit</source>
         <translation>Keluar</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="700"/>
+        <location filename="../ui/mainWindow.ui" line="726"/>
         <source>Open</source>
         <translation>Buka</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="705"/>
+        <location filename="../ui/mainWindow.ui" line="731"/>
         <source>About</source>
         <translation>Tentang</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="710"/>
+        <location filename="../ui/mainWindow.ui" line="736"/>
         <source>External Editor</source>
         <translation>Editor eksternal</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="715"/>
+        <location filename="../ui/mainWindow.ui" line="741"/>
         <source>Open CQ Database</source>
         <translation>CQ buka Database</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="720"/>
+        <location filename="../ui/mainWindow.ui" line="746"/>
         <source>Language</source>
         <translation>Bahasa</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="725"/>
+        <location filename="../ui/mainWindow.ui" line="751"/>
         <source>About Qt</source>
         <translation>Tentang Qt</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="733"/>
+        <location filename="../ui/mainWindow.ui" line="759"/>
         <source>File Viewer Settings</source>
         <translation>Pengaturan file Viewer</translation>
     </message>
@@ -267,12 +273,12 @@
 <context>
     <name>aboutDialog</name>
     <message>
-        <location filename="../ui/aboutDialog.ui" line="20"/>
+        <location filename="../ui/aboutDialog.ui" line="23"/>
         <source>About CodeQuery</source>
         <translation>Tentang CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/aboutDialog.ui" line="116"/>
+        <location filename="../ui/aboutDialog.ui" line="119"/>
         <source>OK</source>
         <translation>Oke</translation>
     </message>
@@ -280,23 +286,23 @@
 <context>
     <name>cqDialogGraph</name>
     <message>
-        <location filename="../graphdialog.cpp" line="89"/>
+        <location filename="../graphdialog.cpp" line="81"/>
         <source>Images</source>
         <translation>Gambar</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="92"/>
+        <location filename="../graphdialog.cpp" line="84"/>
         <source>Export Image</source>
         <translation>Ekspor gambar</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="103"/>
-        <location filename="../graphdialog.cpp" line="122"/>
+        <location filename="../graphdialog.cpp" line="95"/>
+        <location filename="../graphdialog.cpp" line="114"/>
         <source>File could not be saved!</source>
         <translation>File tidak bisa diselamatkan!</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="111"/>
+        <location filename="../graphdialog.cpp" line="103"/>
         <source>Export DOT file</source>
         <translation>Mengekspor DOT file</translation>
     </message>
@@ -304,32 +310,32 @@
 <context>
     <name>fileViewSettingsDialog</name>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="14"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="17"/>
         <source>File Viewer Settings</source>
         <translation>Pengaturan file Viewer</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="33"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="36"/>
         <source>Font</source>
         <translation>Font</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="46"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="49"/>
         <source>Syntax highlight theme</source>
         <translation>Sintaks sorot tema</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="59"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="62"/>
         <source>Tab Width (number of spaces)</source>
         <translation>Tab lebar (jumlah ruang)</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="119"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="122"/>
         <source>Cancel</source>
         <translation>Batal</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="132"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="135"/>
         <source>OK</source>
         <translation>Oke</translation>
     </message>
@@ -337,62 +343,62 @@
 <context>
     <name>fileviewer</name>
     <message>
-        <location filename="../fileviewer.cpp" line="249"/>
+        <location filename="../fileviewer.cpp" line="248"/>
         <source>File not found</source>
         <translation>File tidak ditemukan</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="256"/>
+        <location filename="../fileviewer.cpp" line="255"/>
         <source>File could not be opened</source>
         <translation>File tidak bisa dibuka</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="270"/>
+        <location filename="../fileviewer.cpp" line="269"/>
         <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
         <translation>File sumber untuk dilihat lebih baru daripada CodeQuery database file. Anda disarankan untuk secara manual regenerasi CodeQuery database file.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="533"/>
+        <location filename="../fileviewer.cpp" line="557"/>
         <source>Cancel</source>
         <translation>Batal</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="534"/>
+        <location filename="../fileviewer.cpp" line="558"/>
         <source>OK</source>
         <translation>Oke</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="536"/>
+        <location filename="../fileviewer.cpp" line="560"/>
         <source>External Editor Configuration</source>
         <translation>Konfigurasi eksternal Editor</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="537"/>
+        <location filename="../fileviewer.cpp" line="561"/>
         <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
         <translation>Harap masukkan path dan argumen untuk editor eksternal. Ganti sebagai berikut:</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="539"/>
+        <location filename="../fileviewer.cpp" line="563"/>
         <source>for file path</source>
         <translation>untuk file path</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="541"/>
+        <location filename="../fileviewer.cpp" line="565"/>
         <source>for line number</source>
         <translation>untuk nomor baris</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="543"/>
+        <location filename="../fileviewer.cpp" line="567"/>
         <source>For example:</source>
         <translation>Sebagai contoh:</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="568"/>
+        <location filename="../fileviewer.cpp" line="592"/>
         <source>File could not be opened!</source>
         <translation>File tidak bisa dibuka!</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="593"/>
+        <location filename="../fileviewer.cpp" line="617"/>
         <source>External editor could not be started. Please check Options!</source>
         <translation>Editor eksternal tidak dapat dimulai. Silakan periksa pilihan!</translation>
     </message>
@@ -400,22 +406,22 @@
 <context>
     <name>listhandler</name>
     <message>
-        <location filename="../listhandler.cpp" line="129"/>
+        <location filename="../listhandler.cpp" line="125"/>
         <source>Symbol</source>
         <translation>Simbol</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="130"/>
+        <location filename="../listhandler.cpp" line="126"/>
         <source>File</source>
         <translation>File</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="133"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Line</source>
         <translation>Baris</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="133"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Preview</source>
         <translation>Tinjauan</translation>
     </message>
@@ -423,22 +429,22 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="168"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>Cancel</source>
         <translation>Batal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="169"/>
+        <location filename="../mainwindow.cpp" line="161"/>
         <source>OK</source>
         <translation>Oke</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="163"/>
         <source>Language</source>
         <translation>Bahasa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="172"/>
+        <location filename="../mainwindow.cpp" line="164"/>
         <source>Select language:</source>
         <translation>Pilih bahasa:</translation>
     </message>
@@ -446,138 +452,138 @@
 <context>
     <name>searchhandler</name>
     <message>
-        <location filename="../searchhandler.cpp" line="334"/>
+        <location filename="../searchhandler.cpp" line="346"/>
         <source>Symbol</source>
         <translation>Simbol</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="337"/>
+        <location filename="../searchhandler.cpp" line="349"/>
         <source>Function or macro definition (Graph available)</source>
         <translation>Definisi fungsi atau makro (grafik tersedia)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="349"/>
+        <location filename="../searchhandler.cpp" line="361"/>
         <source>Class or struct (Graph available)</source>
         <translation>Kelas atau struct (grafik tersedia)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="343"/>
+        <location filename="../searchhandler.cpp" line="355"/>
         <source>Functions calling this function</source>
         <translation>Fungsi-fungsi yang memanggil fungsi ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="346"/>
+        <location filename="../searchhandler.cpp" line="358"/>
         <source>Functions called by this function</source>
         <translation>Fungsi-fungsi yang disebut oleh fungsi ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="340"/>
+        <location filename="../searchhandler.cpp" line="352"/>
         <source>Calls of this function or macro</source>
         <translation>Panggilan ini fungsi atau makro</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="352"/>
+        <location filename="../searchhandler.cpp" line="364"/>
         <source>Class which owns this member or method</source>
         <translation>Kelas yang memiliki anggota atau metode ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="355"/>
+        <location filename="../searchhandler.cpp" line="367"/>
         <source>Members or methods of this class</source>
         <translation>Anggota atau metode kelas ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="358"/>
+        <location filename="../searchhandler.cpp" line="370"/>
         <source>Parent of this class</source>
         <translation>Orang tua dari kelas ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="361"/>
+        <location filename="../searchhandler.cpp" line="373"/>
         <source>Children of this class</source>
         <translation>Anak-anak kelas ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="364"/>
+        <location filename="../searchhandler.cpp" line="376"/>
         <source>Files including this file</source>
         <translation>File termasuk file ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="367"/>
+        <location filename="../searchhandler.cpp" line="379"/>
         <source>Full path for file</source>
         <translation>Path lengkap untuk file</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="370"/>
+        <location filename="../searchhandler.cpp" line="382"/>
         <source>Functions or macros inside this file</source>
         <translation>Fungsi atau Macro di dalam file ini</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="381"/>
+        <location filename="../searchhandler.cpp" line="393"/>
         <source>CodeQuery DB Files</source>
         <translation>CodeQuery DB file</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="384"/>
+        <location filename="../searchhandler.cpp" line="396"/>
         <source>Open CQ database file</source>
         <translation>Buka file database CQ</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="453"/>
+        <location filename="../searchhandler.cpp" line="465"/>
         <source>Function Call Graph</source>
         <translation>Grafik fungsi panggilan</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="457"/>
+        <location filename="../searchhandler.cpp" line="469"/>
         <source>Class Inheritance Graph</source>
         <translation>Kelas warisan grafik</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="473"/>
-        <location filename="../searchhandler.cpp" line="476"/>
+        <location filename="../searchhandler.cpp" line="485"/>
+        <location filename="../searchhandler.cpp" line="488"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>Jika pencocokan sama persis dimatikan, pencarian wildcard (* dan?) yang didukung</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="548"/>
+        <location filename="../searchhandler.cpp" line="560"/>
         <source>results found</source>
         <translation>hasil ditemukan</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="567"/>
+        <location filename="../searchhandler.cpp" line="579"/>
         <source>in progress</source>
         <translation>sedang berlangsung</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="568"/>
+        <location filename="../searchhandler.cpp" line="580"/>
         <source>Cancel</source>
         <translation>Batal</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="665"/>
+        <location filename="../searchhandler.cpp" line="677"/>
         <source>You have to first select an item from the list before pushing the Graph button.</source>
         <translation>Anda harus memilih dulu item dari daftar sebelum menekan tombol grafik.</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="794"/>
+        <location filename="../searchhandler.cpp" line="806"/>
         <source>File open error</source>
         <translation>Buka file kesalahan</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="795"/>
+        <location filename="../searchhandler.cpp" line="807"/>
         <source>Wrong file format</source>
         <translation>Format file salah</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="796"/>
+        <location filename="../searchhandler.cpp" line="808"/>
         <source>Incorrect CQ database version</source>
         <translation>Salah CQ database versi</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="797"/>
+        <location filename="../searchhandler.cpp" line="809"/>
         <source>OK</source>
         <translation>Oke</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="799"/>
+        <location filename="../searchhandler.cpp" line="811"/>
         <source>Unknown Error</source>
         <translation>Error tidak diketahui</translation>
     </message>
