@@ -4,50 +4,50 @@
 <context>
     <name>DialogGraph</name>
     <message>
-        <location filename="../ui/graphDialog.ui" line="14"/>
+        <location filename="../ui/graphDialog.ui" line="17"/>
         <source>Graph</source>
         <translation>그래프</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="23"/>
+        <location filename="../ui/graphDialog.ui" line="26"/>
         <source>Please wait ...</source>
         <translation>잠시만 기다려 주십시오...</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="70"/>
         <location filename="../ui/graphDialog.ui" line="73"/>
+        <location filename="../ui/graphDialog.ui" line="76"/>
         <source>Zoom Out</source>
         <translation>축소</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="93"/>
         <location filename="../ui/graphDialog.ui" line="96"/>
+        <location filename="../ui/graphDialog.ui" line="99"/>
         <source>Zoom In</source>
         <translation>확대</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="123"/>
+        <location filename="../ui/graphDialog.ui" line="126"/>
         <source>Number of levels:</source>
         <translation>수준의 수:</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="153"/>
         <location filename="../ui/graphDialog.ui" line="156"/>
         <location filename="../ui/graphDialog.ui" line="159"/>
+        <location filename="../ui/graphDialog.ui" line="162"/>
         <source>Save to DOT file</source>
         <translation>점 파일에 저장</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="172"/>
         <location filename="../ui/graphDialog.ui" line="175"/>
         <location filename="../ui/graphDialog.ui" line="178"/>
+        <location filename="../ui/graphDialog.ui" line="181"/>
         <source>Save Image</source>
         <translation>이미지 저장</translation>
     </message>
     <message>
-        <location filename="../ui/graphDialog.ui" line="191"/>
         <location filename="../ui/graphDialog.ui" line="194"/>
         <location filename="../ui/graphDialog.ui" line="197"/>
+        <location filename="../ui/graphDialog.ui" line="200"/>
         <source>Close</source>
         <translation>닫기</translation>
     </message>
@@ -55,211 +55,217 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../ui/mainWindow.ui" line="14"/>
+        <location filename="../ui/mainWindow.ui" line="17"/>
         <source>CodeQuery</source>
         <translation>CodeQuery</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="27"/>
         <location filename="../ui/mainWindow.ui" line="30"/>
+        <location filename="../ui/mainWindow.ui" line="33"/>
         <source>Open Database</source>
         <translation>데이터베이스 열기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="76"/>
+        <location filename="../ui/mainWindow.ui" line="79"/>
         <source>Auto-complete</source>
         <translation>자동 완성</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="90"/>
+        <location filename="../ui/mainWindow.ui" line="93"/>
         <source>Exact match</source>
         <translation>정확 하 게 일치</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="104"/>
         <location filename="../ui/mainWindow.ui" line="107"/>
+        <location filename="../ui/mainWindow.ui" line="110"/>
         <source>File path filter</source>
         <translation>파일 경로 필터</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="110"/>
+        <location filename="../ui/mainWindow.ui" line="113"/>
         <source>Filter</source>
         <translation>필터</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="126"/>
         <location filename="../ui/mainWindow.ui" line="129"/>
+        <location filename="../ui/mainWindow.ui" line="132"/>
         <source>File path filter, wildcard searches (* and ?) are supported</source>
         <translation>파일 경로 필터, 와일드 카드 검색 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="152"/>
         <location filename="../ui/mainWindow.ui" line="155"/>
+        <location filename="../ui/mainWindow.ui" line="158"/>
         <source>Previous search term</source>
         <translation>이전 검색어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="175"/>
         <location filename="../ui/mainWindow.ui" line="178"/>
+        <location filename="../ui/mainWindow.ui" line="181"/>
         <source>Next search term</source>
         <translation>다음 검색어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="204"/>
         <location filename="../ui/mainWindow.ui" line="207"/>
+        <location filename="../ui/mainWindow.ui" line="210"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>정확히 일치 하는 와일드 카드 검색을 전환 하는 경우 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="226"/>
         <location filename="../ui/mainWindow.ui" line="229"/>
+        <location filename="../ui/mainWindow.ui" line="232"/>
         <source>Search</source>
         <translation>검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="249"/>
         <location filename="../ui/mainWindow.ui" line="252"/>
+        <location filename="../ui/mainWindow.ui" line="255"/>
         <source>Paste and Search</source>
         <translation>붙여넣기 및 검색</translation>
     </message>
     <message>
         <location filename="../ui/mainWindow.ui" line="275"/>
         <location filename="../ui/mainWindow.ui" line="278"/>
+        <source>List of all files</source>
+        <translation>모든 파일의 목록</translation>
+    </message>
+    <message>
+        <location filename="../ui/mainWindow.ui" line="301"/>
+        <location filename="../ui/mainWindow.ui" line="304"/>
         <source>Draw graph</source>
         <translation>그래프 그리기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="335"/>
-        <location filename="../ui/mainWindow.ui" line="338"/>
+        <location filename="../ui/mainWindow.ui" line="361"/>
+        <location filename="../ui/mainWindow.ui" line="364"/>
         <source>Previous File</source>
         <translation>이전 파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="358"/>
-        <location filename="../ui/mainWindow.ui" line="361"/>
+        <location filename="../ui/mainWindow.ui" line="384"/>
+        <location filename="../ui/mainWindow.ui" line="387"/>
         <source>Next File</source>
         <translation>다음 파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="381"/>
-        <location filename="../ui/mainWindow.ui" line="384"/>
+        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="410"/>
         <source>Open in Editor</source>
         <translation>편집기에서 열려</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="404"/>
-        <location filename="../ui/mainWindow.ui" line="407"/>
+        <location filename="../ui/mainWindow.ui" line="430"/>
+        <location filename="../ui/mainWindow.ui" line="433"/>
         <source>Go to selected line</source>
         <translation>선택 된 줄으로 이동</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="427"/>
-        <location filename="../ui/mainWindow.ui" line="430"/>
+        <location filename="../ui/mainWindow.ui" line="453"/>
+        <location filename="../ui/mainWindow.ui" line="456"/>
         <source>Reduce font size</source>
         <translation>글꼴 크기 줄이기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="450"/>
-        <location filename="../ui/mainWindow.ui" line="453"/>
+        <location filename="../ui/mainWindow.ui" line="476"/>
+        <location filename="../ui/mainWindow.ui" line="479"/>
         <source>Increase font size</source>
         <translation>글꼴 크기 증가</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="480"/>
-        <location filename="../ui/mainWindow.ui" line="483"/>
+        <location filename="../ui/mainWindow.ui" line="506"/>
+        <location filename="../ui/mainWindow.ui" line="509"/>
         <source>Copy, paste and search</source>
         <translation>복사, 붙여넣기 및 검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="503"/>
-        <location filename="../ui/mainWindow.ui" line="506"/>
+        <location filename="../ui/mainWindow.ui" line="529"/>
+        <location filename="../ui/mainWindow.ui" line="532"/>
         <source>Symbol search only for paste and search</source>
         <translation>붙여넣기 및 검색에 대해서만 기호 검색</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="509"/>
+        <location filename="../ui/mainWindow.ui" line="535"/>
         <source>Symbol only</source>
         <translation>상징만</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="523"/>
-        <location filename="../ui/mainWindow.ui" line="526"/>
+        <location filename="../ui/mainWindow.ui" line="549"/>
+        <location filename="../ui/mainWindow.ui" line="552"/>
         <source>Previous search result in this file</source>
         <translation>이 파일에서 이전 검색 결과</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="546"/>
-        <location filename="../ui/mainWindow.ui" line="549"/>
+        <location filename="../ui/mainWindow.ui" line="572"/>
+        <location filename="../ui/mainWindow.ui" line="575"/>
         <source>Next search result in this file</source>
         <translation>이 파일에서 다음 검색 결과</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="581"/>
+        <location filename="../ui/mainWindow.ui" line="607"/>
         <source>FilePath:0</source>
         <translation>FilePath:0</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="610"/>
+        <location filename="../ui/mainWindow.ui" line="636"/>
         <source>Sort by line number</source>
         <translation>줄 번호로 정렬 합니다</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="615"/>
+        <location filename="../ui/mainWindow.ui" line="641"/>
         <source>Sort by name</source>
         <translation>이름으로 정렬 합니다</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="665"/>
+        <location filename="../ui/mainWindow.ui" line="691"/>
         <source>File</source>
         <translation>파일</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="672"/>
+        <location filename="../ui/mainWindow.ui" line="698"/>
         <source>Options</source>
         <translation>옵션</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="680"/>
+        <location filename="../ui/mainWindow.ui" line="706"/>
         <source>Help</source>
         <translation>도움말</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="692"/>
+        <location filename="../ui/mainWindow.ui" line="718"/>
         <source>Exit</source>
         <translation>출구</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="700"/>
+        <location filename="../ui/mainWindow.ui" line="726"/>
         <source>Open</source>
         <translation>오픈</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="705"/>
+        <location filename="../ui/mainWindow.ui" line="731"/>
         <source>About</source>
         <translation>에 대 한</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="710"/>
+        <location filename="../ui/mainWindow.ui" line="736"/>
         <source>External Editor</source>
         <translation>외부 편집기</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="715"/>
+        <location filename="../ui/mainWindow.ui" line="741"/>
         <source>Open CQ Database</source>
         <translation>오픈 CQ 데이터베이스</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="720"/>
+        <location filename="../ui/mainWindow.ui" line="746"/>
         <source>Language</source>
         <translation>언어</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="725"/>
+        <location filename="../ui/mainWindow.ui" line="751"/>
         <source>About Qt</source>
         <translation>Qt에 대 한</translation>
     </message>
     <message>
-        <location filename="../ui/mainWindow.ui" line="733"/>
+        <location filename="../ui/mainWindow.ui" line="759"/>
         <source>File Viewer Settings</source>
         <translation>파일 뷰어 설정</translation>
     </message>
@@ -267,12 +273,12 @@
 <context>
     <name>aboutDialog</name>
     <message>
-        <location filename="../ui/aboutDialog.ui" line="20"/>
+        <location filename="../ui/aboutDialog.ui" line="23"/>
         <source>About CodeQuery</source>
         <translation>CodeQuery에 대 한</translation>
     </message>
     <message>
-        <location filename="../ui/aboutDialog.ui" line="116"/>
+        <location filename="../ui/aboutDialog.ui" line="119"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
@@ -280,23 +286,23 @@
 <context>
     <name>cqDialogGraph</name>
     <message>
-        <location filename="../graphdialog.cpp" line="89"/>
+        <location filename="../graphdialog.cpp" line="81"/>
         <source>Images</source>
         <translation>이미지</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="92"/>
+        <location filename="../graphdialog.cpp" line="84"/>
         <source>Export Image</source>
         <translation>이미지 내보내기</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="103"/>
-        <location filename="../graphdialog.cpp" line="122"/>
+        <location filename="../graphdialog.cpp" line="95"/>
+        <location filename="../graphdialog.cpp" line="114"/>
         <source>File could not be saved!</source>
         <translation>파일을 저장할 수 없습니다!</translation>
     </message>
     <message>
-        <location filename="../graphdialog.cpp" line="111"/>
+        <location filename="../graphdialog.cpp" line="103"/>
         <source>Export DOT file</source>
         <translation>도트 파일 내보내기</translation>
     </message>
@@ -304,32 +310,32 @@
 <context>
     <name>fileViewSettingsDialog</name>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="14"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="17"/>
         <source>File Viewer Settings</source>
         <translation>파일 뷰어 설정</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="33"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="36"/>
         <source>Font</source>
         <translation>글꼴</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="46"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="49"/>
         <source>Syntax highlight theme</source>
         <translation>구문 하이라이트 테마</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="59"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="62"/>
         <source>Tab Width (number of spaces)</source>
         <translation>탭 너비 (공백 수)</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="119"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="122"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../ui/fileViewSettingsDialog.ui" line="132"/>
+        <location filename="../ui/fileViewSettingsDialog.ui" line="135"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
@@ -337,62 +343,62 @@
 <context>
     <name>fileviewer</name>
     <message>
-        <location filename="../fileviewer.cpp" line="249"/>
+        <location filename="../fileviewer.cpp" line="248"/>
         <source>File not found</source>
         <translation>파일을 찾을 수 없습니다</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="256"/>
+        <location filename="../fileviewer.cpp" line="255"/>
         <source>File could not be opened</source>
         <translation>파일을 열 수 없습니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="270"/>
+        <location filename="../fileviewer.cpp" line="269"/>
         <source>The source file to be viewed is newer than the CodeQuery database file. You are recommended to manually regenerate the CodeQuery database file.</source>
         <translation>소스 파일을 볼 수 CodeQuery 데이터베이스 파일 보다 최신입니다. CodeQuery 데이터베이스 파일을 수동으로 다시 생성 하는 것이 좋습니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="533"/>
+        <location filename="../fileviewer.cpp" line="557"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="534"/>
+        <location filename="../fileviewer.cpp" line="558"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="536"/>
+        <location filename="../fileviewer.cpp" line="560"/>
         <source>External Editor Configuration</source>
         <translation>외부 편집기 구성</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="537"/>
+        <location filename="../fileviewer.cpp" line="561"/>
         <source>Please enter the path and arguments for the external editor. Replace as follows:</source>
         <translation>경로 및 외부 편집기에 대 한 인수를 입력 해 주시기 바랍니다. 다음과 같이 바꿉니다.</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="539"/>
+        <location filename="../fileviewer.cpp" line="563"/>
         <source>for file path</source>
         <translation>파일 경로 대 한</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="541"/>
+        <location filename="../fileviewer.cpp" line="565"/>
         <source>for line number</source>
         <translation>줄 번호에 대 한</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="543"/>
+        <location filename="../fileviewer.cpp" line="567"/>
         <source>For example:</source>
         <translation>예를 들어:</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="568"/>
+        <location filename="../fileviewer.cpp" line="592"/>
         <source>File could not be opened!</source>
         <translation>파일을 열 수 없습니다!</translation>
     </message>
     <message>
-        <location filename="../fileviewer.cpp" line="593"/>
+        <location filename="../fileviewer.cpp" line="617"/>
         <source>External editor could not be started. Please check Options!</source>
         <translation>외부 편집기를 시작할 수 없습니다. 옵션을 확인 하십시오!</translation>
     </message>
@@ -400,22 +406,22 @@
 <context>
     <name>listhandler</name>
     <message>
-        <location filename="../listhandler.cpp" line="129"/>
+        <location filename="../listhandler.cpp" line="125"/>
         <source>Symbol</source>
         <translation>기호</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="130"/>
+        <location filename="../listhandler.cpp" line="126"/>
         <source>File</source>
         <translation>파일</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="133"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Line</source>
         <translation>선</translation>
     </message>
     <message>
-        <location filename="../listhandler.cpp" line="133"/>
+        <location filename="../listhandler.cpp" line="129"/>
         <source>Preview</source>
         <translation>미리 보기</translation>
     </message>
@@ -423,22 +429,22 @@
 <context>
     <name>mainwindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="168"/>
+        <location filename="../mainwindow.cpp" line="160"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="169"/>
+        <location filename="../mainwindow.cpp" line="161"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="163"/>
         <source>Language</source>
         <translation>언어</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="172"/>
+        <location filename="../mainwindow.cpp" line="164"/>
         <source>Select language:</source>
         <translation>언어 선택:</translation>
     </message>
@@ -446,138 +452,138 @@
 <context>
     <name>searchhandler</name>
     <message>
-        <location filename="../searchhandler.cpp" line="334"/>
+        <location filename="../searchhandler.cpp" line="346"/>
         <source>Symbol</source>
         <translation>기호</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="337"/>
+        <location filename="../searchhandler.cpp" line="349"/>
         <source>Function or macro definition (Graph available)</source>
         <translation>함수 또는 매크로 정의 (그래프 제공)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="349"/>
+        <location filename="../searchhandler.cpp" line="361"/>
         <source>Class or struct (Graph available)</source>
         <translation>클래스 또는 구조체 (그래프 제공)</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="343"/>
+        <location filename="../searchhandler.cpp" line="355"/>
         <source>Functions calling this function</source>
         <translation>이 함수를 호출 하는 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="346"/>
+        <location filename="../searchhandler.cpp" line="358"/>
         <source>Functions called by this function</source>
         <translation>이 함수에 의해 호출 된 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="340"/>
+        <location filename="../searchhandler.cpp" line="352"/>
         <source>Calls of this function or macro</source>
         <translation>이 함수 또는 매크로의 호출</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="352"/>
+        <location filename="../searchhandler.cpp" line="364"/>
         <source>Class which owns this member or method</source>
         <translation>클래스 멤버 또는 메서드가 소유 하 고 있는</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="355"/>
+        <location filename="../searchhandler.cpp" line="367"/>
         <source>Members or methods of this class</source>
         <translation>회원 또는이 클래스의 메서드</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="358"/>
+        <location filename="../searchhandler.cpp" line="370"/>
         <source>Parent of this class</source>
         <translation>이 클래스의 부모</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="361"/>
+        <location filename="../searchhandler.cpp" line="373"/>
         <source>Children of this class</source>
         <translation>이 클래스의 자식</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="364"/>
+        <location filename="../searchhandler.cpp" line="376"/>
         <source>Files including this file</source>
         <translation>이 파일을 포함 한 파일</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="367"/>
+        <location filename="../searchhandler.cpp" line="379"/>
         <source>Full path for file</source>
         <translation>파일의 전체 경로</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="370"/>
+        <location filename="../searchhandler.cpp" line="382"/>
         <source>Functions or macros inside this file</source>
         <translation>이 파일 안에 매크로 또는 함수</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="381"/>
+        <location filename="../searchhandler.cpp" line="393"/>
         <source>CodeQuery DB Files</source>
         <translation>CodeQuery DB 파일</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="384"/>
+        <location filename="../searchhandler.cpp" line="396"/>
         <source>Open CQ database file</source>
         <translation>CQ 데이터베이스 파일 열기</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="453"/>
+        <location filename="../searchhandler.cpp" line="465"/>
         <source>Function Call Graph</source>
         <translation>함수 호출 그래프</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="457"/>
+        <location filename="../searchhandler.cpp" line="469"/>
         <source>Class Inheritance Graph</source>
         <translation>클래스 상속 그래프</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="473"/>
-        <location filename="../searchhandler.cpp" line="476"/>
+        <location filename="../searchhandler.cpp" line="485"/>
+        <location filename="../searchhandler.cpp" line="488"/>
         <source>If Exact Match is switched off, wildcard searches (* and ?) are supported</source>
         <translation>정확히 일치 하는 와일드 카드 검색을 전환 하는 경우 (* 및?) 지원</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="548"/>
+        <location filename="../searchhandler.cpp" line="560"/>
         <source>results found</source>
         <translation>찾은 결과</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="567"/>
+        <location filename="../searchhandler.cpp" line="579"/>
         <source>in progress</source>
         <translation>진행 중</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="568"/>
+        <location filename="../searchhandler.cpp" line="580"/>
         <source>Cancel</source>
         <translation>취소</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="665"/>
+        <location filename="../searchhandler.cpp" line="677"/>
         <source>You have to first select an item from the list before pushing the Graph button.</source>
         <translation>먼저 그래프 버튼을 추진 하기 전에 목록에서 항목을 선택 해야 합니다.</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="794"/>
+        <location filename="../searchhandler.cpp" line="806"/>
         <source>File open error</source>
         <translation>파일 열기 오류</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="795"/>
+        <location filename="../searchhandler.cpp" line="807"/>
         <source>Wrong file format</source>
         <translation>잘못 된 파일 형식</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="796"/>
+        <location filename="../searchhandler.cpp" line="808"/>
         <source>Incorrect CQ database version</source>
         <translation>잘못 된 CQ 데이터베이스 버전</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="797"/>
+        <location filename="../searchhandler.cpp" line="809"/>
         <source>OK</source>
         <translation>괜찮았던 것</translation>
     </message>
     <message>
-        <location filename="../searchhandler.cpp" line="799"/>
+        <location filename="../searchhandler.cpp" line="811"/>
         <source>Unknown Error</source>
         <translation>알 수 없는 오류</translation>
     </message>
