@@ -1,21 +1,12 @@
 
 /*
  * CodeQuery
- * Copyright (C) 2013-2016 ruben2020 https://github.com/ruben2020/
- * 
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (C) 2013-2017 ruben2020 https://github.com/ruben2020/
  * 
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
  */
 
 
@@ -29,7 +20,9 @@ sqlbase::sqlbase()
 
 sqlbase::~sqlbase()
 {
-	sqlite3_close(m_db);
+	if (m_db)
+		sqlite3_close(m_db);
+	m_db = 0;
 }
 
 void sqlbase::setDebug(bool val)
