@@ -48,6 +48,7 @@
 #define SQL_CHILDCLASS "SELECT symtbl.symName,symtbl.symType,filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.lineID=linestbl.lineID AND symtbl.symID IN (SELECT childID FROM inherittbl WHERE parentID IN (SELECT symID FROM symtbl WHERE symName LIKE ? ESCAPE \";\")) INNER JOIN filestbl ON (linestbl.fileID=filestbl.fileID AND filestbl.filePath LIKE ? ESCAPE \";\");"
 #define SQL_INCLUDE "SELECT filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.lineID=linestbl.lineID AND symtbl.symID IN (SELECT symID FROM symtbl WHERE symName LIKE ? ESCAPE \";\" AND symType=\"~\") INNER JOIN filestbl ON linestbl.fileID=filestbl.fileID;"
 #define SQL_FILEPATH "SELECT DISTINCT filePath FROM filestbl WHERE filePath LIKE ? ESCAPE \";\";"
+#define SQL_FILESLIST "SELECT DISTINCT filePath FROM filestbl WHERE filePath LIKE ? ESCAPE \";\" ORDER BY filePath ASC;"
 #define SQL_AUTOCOMPLETE "SELECT DISTINCT symName FROM symtbl WHERE symName LIKE ? ORDER BY symName LIMIT 20;"
 #define SQL_FUNCSINFILE "SELECT symtbl.symName,symtbl.symType,filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.lineID=linestbl.lineID AND symtbl.symID IN (SELECT symID FROM symtbl WHERE (symtbl.symType=\"$\" OR symtbl.symType=\"#\")) INNER JOIN filestbl ON (linestbl.fileID=filestbl.fileID AND filestbl.filePath LIKE ? ESCAPE \";\");"
 
@@ -67,6 +68,7 @@
 #define SQL_EM_CHILDCLASS "SELECT symtbl.symName,symtbl.symType,filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.lineID=linestbl.lineID AND symtbl.symID IN (SELECT childID FROM inherittbl WHERE parentID IN (SELECT symID FROM symtbl WHERE symName=?)) INNER JOIN filestbl ON (linestbl.fileID=filestbl.fileID AND filestbl.filePath LIKE ? ESCAPE \";\");"
 #define SQL_EM_INCLUDE "SELECT filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.lineID=linestbl.lineID AND symtbl.symID IN (SELECT symID FROM symtbl WHERE symName=? AND symType=\"~\") INNER JOIN filestbl ON linestbl.fileID=filestbl.fileID;"
 #define SQL_EM_FILEPATH "SELECT DISTINCT filePath FROM filestbl WHERE filePath=?;"
+#define SQL_EM_FILESLIST "SELECT DISTINCT filePath FROM filestbl WHERE filePath=? ORDER BY filePath ASC;"
 #define SQL_DECLARATION "SELECT symtbl.symName,symtbl.symType,filestbl.filePath,linestbl.linenum,linestbl.linetext,linestbl.fileID FROM symtbl INNER JOIN linestbl ON symtbl.symID IN (SELECT symID FROM symtbl WHERE symName=?) AND (symtbl.symType=\"$\" OR symtbl.symType=\"#\" OR symtbl.symType=\"c\" OR symtbl.symType=\"s\") AND symtbl.lineID=linestbl.lineID INNER JOIN filestbl ON (linestbl.fileID=filestbl.fileID) LIMIT 1;"
 
 struct nameasc
@@ -236,6 +238,7 @@ sqlqueryresultlist sqlquery::search_funclist_filename(const char* searchstr)
 {
 	//printf("search_funclist_filename %s\n", searchstr);
 	sqlqueryresultlist result;
+	if (searchstr == NULL) return result;
 	result.result_type = sqlqueryresultlist::sqlresultERROR;
 	tStr srchterm("%");
 	srchterm.append(searchstr);
@@ -323,6 +326,11 @@ sqlqueryresultlist sqlquery::search(
 			resultType = sqlqueryresultlist::sqlresultFILE_ONLY;
 			twoTerms = false;
 			break;
+		case sqlresultFILESLIST:
+			sqlqry = exactmatch ? SQL_EM_FILESLIST : SQL_FILESLIST;
+			resultType = sqlqueryresultlist::sqlresultFILE_ONLY;
+			twoTerms = false;
+			break;
 		case sqlresultCALLINGFUNC:
 			sqlqry = exactmatch ? SQL_EM_CALLINGFUNC : SQL_CALLINGFUNC;
 			break;
@@ -379,7 +387,13 @@ sqlqueryresultlist sqlquery::search(
 	}
 	if (resultType == sqlqueryresultlist::sqlresultFULL) result = search_full(m_searchstmt.get());
 	else if (resultType == sqlqueryresultlist::sqlresultFILE_LINE) result = search_file_line(m_searchstmt.get());
-	else if (resultType == sqlqueryresultlist::sqlresultFILE_ONLY) result = search_file_only(m_searchstmt.get());
+	else if (resultType == sqlqueryresultlist::sqlresultFILE_ONLY)
+	{
+		if (querytype == sqlresultFILESLIST)
+			result = search_filepath_only(m_searchstmt.get());
+		else
+			result = search_file_only(m_searchstmt.get());
+	}
 	return result;
 }	
 
@@ -613,6 +627,40 @@ sqlqueryresultlist sqlquery::search_file_only(sqlite3_stmt* stmt)
 	return result;
 }
 
-
-
+sqlqueryresultlist sqlquery::search_filepath_only(sqlite3_stmt* stmt)
+{
+	int rc;
+	sqlqueryresultlist result;
+	tStr fp;
+	result.result_type = sqlqueryresultlist::sqlresultERROR;
+	sqlqueryresult item;
+	do
+	{
+		rc = sqlite3_step(stmt);
+		if (rc == SQLITE_ROW)
+		{
+			fp            = (const char*) sqlite3_column_text(stmt, 0);
+			item.linenum  = "1";
+			item.filename = fp;
+			if (isAbsolutePath(fp) == false)
+			{
+				item.filepath = m_basepath;
+				item.filepath += DIRSEP;
+				item.filepath += fp;
+			}
+			else item.filepath = fp;
+			result.resultlist.push_back(item);
+		}
+	} while (rc == SQLITE_ROW);
+	if (rc != SQLITE_DONE)
+	{
+		result.result_type = sqlqueryresultlist::sqlresultERROR;
+		result.sqlerrmsg = sqlite3_errmsg(m_db);
+	}
+	else
+	{
+		result.result_type = sqlqueryresultlist::sqlresultFILE_ONLY;
+	}
+	return result;
+}
 
