@@ -1,11 +1,11 @@
 
 /*
  * CodeQuery
- * Copyright (C) 2013 ruben2020 https://github.com/ruben2020/
+ * Copyright (C) 2013-2016 ruben2020 https://github.com/ruben2020/
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
@@ -30,9 +30,7 @@
 class showgraph
 {
 public:
-	showgraph();
-	~showgraph();
-	QImage convertToImage(QString grpxml);
+	static QImage convertToImage(QString grpxml);
 };
 
 
